from ..ar_AA import Provider as ArabicPersonProvider


class Provider(ArabicPersonProvider):
    last_names = (
        "حجار",
        "آل الشيخ",
        "الحجار",
        "حنبولي",
        "آل سعود",
        "آل علي",
        "آل جعفر",
        "أبا الخيل",
        "المهنا",
        "مهنا",
        "بن لادن",
        "كانو",
        "الجفالي",
        "فصيل",
        "آل رفيع",
        "آل بن لافي",
        "آل العسكري",
        "آل بن ظافر",
        "آل عواض",
        "المشاولة",
        "آل مقطة",
        "آل عايض",
        "آل معيض",
        "آل حسين",
        "المغاولة",
        "آل خضير",
        "آل صفوان",
        "آل محمد بن علي بن جماز",
        "آل عطفة",
        "آل قصير",
        "آل سلطان",
        "العليان",
        "الشايع",
        "أبو داوود",
        "الدباغ",
        "العجلان",
        "الراشد",
        "المهيدب",
        "العقيل",
        "شربتلي",
        "الخرافي",
        "أبو داوود",
        "الجابر",
        "بقشان",
        "الحكير",
    )
