from ..ar_AA import Provider as ArabicPersonProvider


class Provider(ArabicPersonProvider):
    last_names = (
        "خوري",
        "شاهين",
        "البرغوثي",
        "الحسيني",
        "الزيدانية",
        "جرار",
        "السكاكيني",
        "طوقان",
        "نسيبة",
        "النشاشيبي",
        "الخازن",
        "ترابين",
        "دغمش",
        "دلاشة",
        "الزيتاوي",
        "صليبا",
        "التركمان",
        "الإغباري",
        "كسواني",
        "جزار",
        "أبو اسنينة",
        "التميمي",
        "الجنيدي",
        "بدر",
        "أبو شقدم",
        "أبو غليون",
        "أبو قمر",
        "الأدغم",
        "حوسة",
        "الصالحي",
        "حمامي",
        "هاشم",
        "الحنبلي",
        "أستيتية",
        "مرمش",
        "قرادة",
        "فطاير",
        "الخماش",
        "الخياط",
        "النعنيش",
        "مهيار",
        "أبو شلبك",
    )
