from .. import Provider as PersonProvider


class Provider(PersonProvider):

    # https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
    language_names = [
        "Afar",
        "Abjasio",
        "Avéstico",
        "Africaans",
        "Akánico",
        "Amhárico",
        "Aragonés",
        "Arábico",
        "Asamés",
        "Avar",
        "Aimara",
        "Azerí",
        "Baskir",
        "Bielorruso",
        "Búlgaro",
        "lenguas Bihari",
        "Bislama",
        "Bambara",
        "Bengalí",
        "Tibetano",
        "Bretón",
        "Bosnio",
        "Catalán",
        "Checheno",
        "Chamorro",
        "Corso",
        "Cree",
        "Checo",
        "Eslavo eclesiástico",
        "Chuvasio",
        "Galés",
        "Danés",
        "Alemán",
        "Maldivo",
        "Dzongkha",
        "Ewé",
        "Griego",
        "Inglés",
        "Esperanto",
        "Español",
        "Estonio",
        "Vasco",
        "Persa",
        "Fula",
        "Finés",
        "Fiyiano",
        "Feroés",
        "Francés",
        "lenguas Frisonas",
        "Irlandés",
        "Gaélico",
        "Gallego",
        "Guaraní",
        "Gujarati",
        "Manés",
        "Hausa",
        "Hebreo",
        "Hindú",
        "Hiri Motu",
        "Croata",
        "Haitiano",
        "Húngaro",
        "Armenio",
        "Herero",
        "Interlingua",
        "Indonés",
        "Igbo",
        "Nuosu",
        "lenguas esquimales",
        "Ido",
        "Islandés",
        "Italiano",
        "Inuit",
        "Japonés",
        "Javanés",
        "Georgiano",
        "Congolés",
        "Kikuyu",
        "Kuanyama",
        "Kazajo",
        "Groenlandés",
        "Camboyano",
        "Canarés",
        "Coreano",
        "Kanurí",
        "Kashmiri Masala",
        "Kurdo",
        "Komi",
        "Córnico",
        "Kirguís",
        "Latín",
        "Luxemburgués",
        "Luganda",
        "Limburgués",
        "Lingala",
        "Lao",
        "Lituano",
        "Kiluba",
        "Letón",
        "Malgache",
        "Marshalés",
        "Maorí",
        "Macedonio",
        "Malabar",
        "Mongol",
        "Marathí",
        "Malayo",
        "Maltés",
        "Birmano",
        "Nauru",
        "Ndebele norte",
        "Nepalí",
        "Ndonga",
        "Neerlandés",
        "Nuevo Noruego",
        "Noruego",
        "Ndebele sur",
        "Navajo",
        "Chichewa",
        "Occitano",
        "Ojibwa",
        "Oromo",
        "Oriya",
        "Osetio",
        "Panyabí",
        "Pali",
        "Polaco",
        "Pastún",
        "Portugués",
        "Quechua",
        "Romanche",
        "Rundi",
        "Rumano",
        "Ruso",
        "Kiñaruanda",
        "Sánscrito",
        "Sardo",
        "Sindi",
        "Sami septentrional",
        "Sango",
        "Cingalés",
        "Eslovaco",
        "Samoano",
        "Shona",
        "Somalí",
        "Albanés",
        "Serbio",
        "Suazi",
        "Sesoto",
        "Sondanés",
        "Sueco",
        "Swahili",
        "Tamil",
        "Télugu",
        "Takiyo",
        "Tailandés",
        "Tigriña",
        "Turcomano",
        "Tagalo",
        "Setsuana",
        "Tongoano",
        "Turco",
        "Tsonga",
        "Tártaro",
        "Tahitiano",
        "Uigur",
        "Ucraniano",
        "Urdu",
        "Uzbeko",
        "Venda",
        "Vietnamita",
        "Valón",
        "Wólof",
        "Xhosa",
        "Yidis",
        "Yoruba",
        "Zhuang",
        "Chino",
        "Zulú",
    ]
